@@ -82,7 +82,7 @@ public:
 
 	/**
 	 * Post a symbol asychrononous event to server.  This sets the
-	 * symbol value, and also generates a @posted:symname event.
+	 * symbol value, and also generates a \@posted:symname event.
 	 *
 	 * @param id of symbol to post.
 	 * @param value of symbol.
@@ -109,9 +109,9 @@ public:
 	 * Get a fully qualified and resolved pathname.
 	 *
 	 * @return pointer to buffer or NULL if invalid.
-	 * @param file path to evaluate.
+	 * @param filename path to evaluate.
 	 * @param buffer to save into.
-	 * @param max size of buffer.
+	 * @param size of buffer.
 	 */
 	const char *getPath(const char *filename, char *buffer, unsigned size);
 
@@ -119,7 +119,7 @@ public:
          * Get and verify partial pathname for file oriented libexec commands.
          *
          * @return pointer to buffer or NULL if invalid.
-         * @param file path to evaluate.
+         * @param filename path to evaluate.
          */
         const char *getFile(const char *filename);
 
@@ -128,16 +128,16 @@ public:
 	 *
 	 * @param voice to set or NULL for default.
 	 */
-	inline void setVoice(const char *v)
-		{voice = v;};
+	inline void setVoice(const char *voice)
+		{voice = voice;};
 
 	/**
 	 * Set the effective audio level for tones...
 	 *
 	 * @param level to set.
 	 */
-	inline void setLevel(Audio::Level l)
-		{level = l;};
+	inline void setLevel(Audio::Level level)
+		{level = level;};
 
 	/**
 	 * Hangup running session...
@@ -153,9 +153,9 @@ public:
 	 * Send a command through to server and capture result.
 	 *
 	 * @return result code.
-	 * @param command to send.
-	 * @param optional query buffer.
-	 * @param optional query size.
+	 * @param text command to send.
+	 * @param buffer for optional query.
+	 * @param size of buffer for optional query.
 	 */
 	result_t sendCommand(const char *text, char *buffer = NULL, unsigned size = 0);
 
@@ -163,7 +163,7 @@ public:
 	 * Send a result to the server.
 	 *
 	 * @return result code from server.
-	 * @param result to send.
+	 * @param text result to send.
 	 */
 	result_t sendResult(const char *text);
 
@@ -173,7 +173,7 @@ public:
 	 * @return result code from server.
 	 * @param destination to transfer.
 	 */
-	result_t xferCall(const char *dest);
+	result_t xferCall(const char *destination);
 
 	/**
 	 * Replay an audio file.
@@ -181,7 +181,7 @@ public:
 	 * @return result code.
 	 * @param name of file to play.
 	 */
-	result_t replayFile(const char *file);
+	result_t replayFile(const char *name);
 
 	/**
 	 * Replay an audio file from a specified offset.
@@ -190,7 +190,7 @@ public:
 	 * @param name of file to play.
 	 * @param offset to play from.
 	 */
-	result_t replayOffset(const char *file, const char *offset);                                                                            
+	result_t replayOffset(const char *name, const char *offset);                                                                            
 
 	/**
 	 * Record an audio file.
@@ -198,15 +198,15 @@ public:
 	 * @return result code.
 	 * @param name of file to record.
 	 * @param total duration of file.
-	 * @param optional silence detect.
+	 * @param silence detect timeout in milliseconds.
 	 */
-	result_t recordFile(const char *file, timeout_t duration, timeout_t silence = 0);
+	result_t recordFile(const char *name, timeout_t total, timeout_t silence = 0);
 
 	/**
 	 * Play a phrase.
 	 *
 	 * @return result code.
-	 * @param text of phrase to play.
+	 * @param format text of phrase to play.
 	 */
 	result_t speak(const char *format, ...);
 
@@ -216,7 +216,7 @@ public:
 	 * @return result code.
 	 * @param name of tone to play.
 	 * @param duration for tone.
-	 * @param audio level of tone.
+	 * @param level of tone.
 	 */
 	result_t playTone(const char *name, timeout_t duration = 0, unsigned level = 0);
 	result_t playSingleTone(short f1, timeout_t duration, unsigned level = 0);
@@ -229,9 +229,9 @@ public:
 	 * @param name of file to record.
 	 * @param offset to record info.
 	 * @param total duration of file.
-	 * @param optional silence detect.
+	 * @param silence detect timer in milliseconds.
 	 */
-	result_t recordOffset(const char *file, const char *offset, timeout_t duration, timeout_t silence = 0);                                                                            
+	result_t recordOffset(const char *name, const char *offset, timeout_t total, timeout_t silence = 0);                                                                            
 
 	/**
 	 * Erase an audio file.
@@ -239,14 +239,14 @@ public:
 	 * @return result code.
 	 * @param name of file to erase.
 	 */
-	result_t eraseFile(const char *file);
+	result_t eraseFile(const char *name);
 
         /**
          * Move an audio file.
          *
          * @return result code.
-         * @param name of file to move.
-	 * @param destination of move.
+         * @param file1 name of file to move.
+	 * @param file2 destination of move.
          */ 
         result_t moveFile(const char *file1, const char *file2);
 
@@ -266,7 +266,7 @@ public:
 	 * Read a line of input.
 	 *
 	 * @return result code.
-	 * @param input buffer.
+	 * @param buffer for input.
 	 * @param size of input buffer.
 	 * @param timeout for input.
 	 */
