@@ -498,6 +498,12 @@ live:
 	keyoptions.setValue("prefix", keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
 
+#ifdef  SCRIPT_SERVER_PREFIX
+        Script::var_prefix = keypaths.getLast("datafiles");
+        Script::etc_prefix = keypaths.getLast("config");
+        Script::log_prefix = keypaths.getLast("logfiles");
+#endif
+
 	// only for live server...
 }
 
@@ -527,7 +533,7 @@ retry:
 
         if(!strnicmp("--", option, 2))
                 ++option;
-
+	
 #ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
