@@ -195,6 +195,10 @@ static void loading(void)
 
 	driver = NULL;	
 	cp = keyengine.getLast("driver");
+	if(cp && !stricmp(cp, "no"))
+		cp = NULL;
+	if(cp && !stricmp(cp, "none"))
+		cp = NULL;
 	if(cp && *cp)
 	{
 		driver = BayonneDriver::loadDriver(cp);
@@ -205,7 +209,11 @@ static void loading(void)
 	{
 		driver = NULL;
 		cp = keyengine.getLast("trunking");
-		if(cp && *cp && strnicmp(cp, "no", 2))
+		if(cp && !stricmp(cp, "no"))
+			cp = NULL;
+		if(cp && !stricmp(cp, "none"))
+			cp = NULL;
+		if(cp)
 			driver = BayonneDriver::loadTrunking(cp);
 		if(driver)
 			loaded = true;
