@@ -45,13 +45,12 @@ using namespace std;
 class ListThread : public ScriptThread, public Dir
 {
 private:
-	const char *prefix, *suffix, *after;
-	Symbol *sym, *save;
+	const char *prefix, *suffix;
+	Symbol *sym;
 	bool longinfo;
 	char filepath[MAX_PATHNAME];
 	unsigned fplen;
 	AudioFile af;
-	char last[65];
 
 	void run(void);
 
@@ -149,6 +148,7 @@ class Runtime : public ScriptRuntime, public Bayonne
 protected:
         unsigned long getTrapMask(const char *trapname);
 
+	static bool testBinding(ScriptInterp *interp, const char *v);
 	static bool testFile(ScriptInterp *interp, const char *v);
 	static bool testDir(ScriptInterp *interp, const char *v);
 	static bool testTimeslot(ScriptInterp *interp, const char *v);
@@ -197,7 +197,6 @@ public:
 	bool scrRoute(void);
 	bool scrErase(void);
 	bool scrMove(void);
-	bool scrLink(void);
 	bool scrCopy(void);
 	bool scrTimeslot(void);
 	bool scrPosition(void);
@@ -220,12 +219,13 @@ public:
 	bool scrDTMF(void);
 	bool scrMF(void);
 	bool scrTransfer(void);
+	bool scrBind(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
 {
 public:
-        const char *chkEndinput(Line *line, ScriptImage *img); 
+	const char *chkEndinput(Line *line, ScriptImage *img);
 	const char *chkBGM(Line *line, ScriptImage *img);
 	const char *chkList(Line *line, ScriptImage *img);
 	const char *chkConfig(Line *line, ScriptImage *img);
@@ -254,12 +254,14 @@ public:
 	const char *chkTransfer(Line *line, ScriptImage *img);
 	const char *chkChildSignal(Line *line, ScriptImage *img);
 	const char *chkDialer(Line *line, ScriptImage *img);
+	const char *chkBind(Line *line, ScriptImage *img);
 };
 
 extern Runtime runtime;
 extern Keydata keypaths;
 extern Keydata keyserver;
 extern Keydata keyengine;
+extern Keydata keyprotocols;
 extern Keydata keyoptions;
 
 extern TimeslotProperty typeTimeslot;
